#!/usr/bin/env python
# coding: utf-8
#dev complete and imported
#test complete and ready to be imported to prod. This is the final version
#prod deployed. this is the final version
# In[21]:


import time
import datetime

class epochtime:

#also add a class to it so it's easily computable or better still make it a module and import
    def date2epoch(date):
        hiredate= date
        pattern = '%d-%m-%Y'
        try:
            epoch = int(time.mktime(time.strptime(hiredate, pattern)))
            return epoch
        except ValueError:
            print("date format is not DD-MM-YYYY.moving to next item")
        except OverflowError:
            print("date format is before 1900.moving to next item")
    def epoch2date(epoch):
        try:
            ndate=datetime.date.fromtimestamp(epoch).strftime('%d-%m-%Y')
        except ValueError:
            print("epoch is wrong. moving to next item")
        except TypeError:
            print("encountered Type error as epoch returned was NULL")
        return ndate
    def epoch2dateeod(epoch):
        try:
            ndate=datetime.date.fromtimestamp(epoch).strftime('%Y-%m-%d')
        except ValueError:
            print("epoch is wrong. moving to next item")
            ndate = None
        except TypeError:
            print("encountered Type error as epoch returned was NULL")
            ndate = None
        return ndate
    def date2epocheod(date):
        hiredate= date
        pattern = '%Y-%m-%d'
        try:
            epoch = int(time.mktime(time.strptime(hiredate, pattern)))
            return epoch
        except ValueError:
            print("date format is not YYYY-MM-DD.moving to next item")
            ndate = None
        except OverflowError:
            print("date format is before 1900.moving to next item")
            ndate = None







#!/usr/bin/env python
# coding: utf-8

# In[29]:
# dev complete and tested. Update the password in dev database
# added the password in codebase in test environment
# test successful and now ready for deployment to Prod.
# production deployed. this is final version
# this is a module makes a connection to a database
import psycopg2 as pgs
import sys
import platform
from requests import get
import platform as os

uname = os.uname()
uname = uname[1]
#print(uname)
try:
    ip = get('https://api.ipify.org').text
except BaseException:
    ip = "127.0.0.1"
    print("couldnt reach internet")
#print ('My public IP address is:', ip)

# connection class - where all functions to connect to a DB are mentioned


class connect:
    # function to create connection
    def create():
        #host_prod = "lykkelle-prod-us-east.postgres.database.azure.com"
        if ip == '213.127.49.192':
            host_prod = "127.0.0.1"
            usr = "postgres"
            mydb = "lykkelledev_db"
            ssl ="disable"
            print("this is connected to main Dev Database")
        elif ip == '20.42.97.74':
            usr = "lykkelle@lykkelle-pgsql-11"
            host_prod = "lykkelle-pgsql-11.postgres.database.azure.com"
            mydb = "lykkelle_db"
            ssl = "require"
            print("this is connected to Prod Database")
        elif '138.91.117.218' in ip:
            usr = "lykkelle@lykkelle-pgsql-11"
            host_prod = "lykkelle-pgsql-11.postgres.database.azure.com"
            mydb = "lykkelletest_db"
            ssl = "require"
            print("This is connected to release database")
        elif '52.188.202.133' in ip:
            usr = "lykkelle@lykkelle-pgsql-11"
            host_prod = "lykkelle-pgsql-11.postgres.database.azure.com"
            mydb = "lykkelletest_db"
            ssl = "require"
            print("This is connected to release database from Web server")
        elif 'LYK' in uname and 'local' in uname:
            host_prod = "127.0.0.1"
            usr = "postgres"
            print("Linking to Dev database as you are not connecting from authorized IPs. Your ip:", ip , "& machine name:",uname)
            mydb = "lykkelledev_db"
            ssl = "disable"
        elif 'LYK' not in uname:
            usr = "lykkelle@lykkelle-pgsql-11"
            host_prod = "lykkelle-pgsql-11.postgres.database.azure.com"
            print("CI/CD Build commencing. Your ip:", ip)
            mydb = "lykkelleut_db"
            ssl = "require"
        else:
            host_prod = "127.0.0.1"
            usr = "postgres"
            print("Linking to Dev database as you are not connecting from authorized IPs. Your ip:", ip , "& machine name:",uname)
            mydb = "lykkelledev_db"
            ssl = "disable"
        try:
            conn = pgs.connect(database=mydb,
                               sslmode = ssl,
                               user=usr,
                               host=host_prod,
                               port="5432",
                               password="Debajyoti86")
        except pgs.Error as e:
            print("Unable to connect!")
            print(e.pgerror)
            sys.exit(1)
        conn.autocommit = True
        cursor = conn.cursor()
        set_path = "SET search_path = dbo"
        cursor.execute(set_path)
        # cursor.execute("select version()")
        # record=cursor.fetchone()
        # print("connection successful and you are connected to","\t",record)
        return conn



#!/usr/bin/env python
# coding: utf-8
#successfully tested. ready to be deployed in Prod
#successfully deployed in Prod. this is the final version
# In[41]:


#finds the last workday from date assigned-1
import datetime as dt
import sys
import numpy as np
import pandas_market_calendars as mcal
class workday:
    date=None
    whol=None
    holilist=[]
#fucntion to store the list of holiays
    def holidays():
        us=mcal.get_calendar('NYSE')
        uk=mcal.get_calendar('LSE')
        eurex=mcal.get_calendar('EUREX')
        us_h=us.holidays()
        uk_h=uk.holidays()
        eurex_h=eurex.holidays()
        us_hol=np.asarray(us_h.holidays)
        uk_hol=np.asarray(uk_h.holidays)
        eurex_hol=np.asarray(eurex_h.holidays)
        hol=[us_hol,uk_hol,eurex_hol]
        holilist=[]
        for i in range (len(hol)):
            myhol=hol[i]
            #print(myhol[0:30])
            for j in range (len(myhol)):#len(myhol)
                edate=myhol[j]
                if int(edate.item().year)==int(dt.date.today().strftime("%Y")):
                    eday=edate.item().day
                    emonth=edate.item().month
                    ehol=str(eday)+"-"+str(emonth)
                    if ehol in holilist:
                        pass
                    else:
                        holilist.append(ehol)
                else:
                    pass;
        return holilist
#function to get the workday
    def __init__(self,date):
        #find the latest workday from input date
        #print("entry variable:",date)
        mlist=[6,7]
        # holilist=workday.holidays()
        try:
            datew=dt.datetime.strptime(date,'%Y-%m-%d').date()
        except ValueError:
            print("The date is wrong. Check format or date entry:",date)
            sys.exit(1)
        # print(datew)
        wday=datew.strftime("%d")
        # print(wday)
        wday = wday.lstrip('0')
        wmonth=datew.strftime("%m")
        wmonth = wmonth.lstrip('0')
        whol=wday+"-"+wmonth
        workday.whol=whol
        wd=datew.isoweekday()
        #print("workday:",wd)
        #print(mlist)
        #print(holilist)
        if (int(wd) in mlist):#or str(whol) in holilist
            recurs=1
        else:
            recurs=0
        #print("recurs:",recurs)
        if recurs==1:
            datew=datew-dt.timedelta(days=1)
            workday.date=datew
            #workday.holilist=holilist
            workday(str(datew))
        else:
            workday.whol=str(whol)
            #print("whole value:",whol,"value stored in self:",workday.whol)
            workday.date=str(datew)
            #workday.holilist=holilist

    def sdate(self):
        return self.date
    # def hlist(self):
    #     return self.holilist
    def hol(self):
        return self.whol






